Entry

Enum Entry 

pub enum Entry<'a> {
    Vacant(VacantEntry<'a>),
    Occupied(OccupiedEntry<'a>),
}
A view into the storage for a particular header name

Variants



Vacant(VacantEntry<'a>)

A mutable view into the location that header values would be inserted into this Headers for the specified HeaderName



Occupied(OccupiedEntry<'a>)

A mutable view into the header values are stored for the specified HeaderName

Implementations

Source

impl<'a> Entry<'a>

pub fn name(&self) -> HeaderName<'_>

retrieve the HeaderName for this entry.

pub fn insert(self, values: impl Into<HeaderValues>) -> &'a mut HeaderValues

Sets the value of the entry, and returns a mutable reference to the inserted value.

Note that this drops any previous occupied value.

pub fn append(self, values: impl Into<HeaderValues>) -> &'a mut HeaderValues

Sets the value of the entry if it is vacant, and appends the new header values to the previous ones if occupied. Returns a mutable reference to the inserted or updated value.

pub fn or_insert_with<V: Into<HeaderValues>>( self, values: impl FnOnce() -> V, ) -> &'a mut HeaderValues

Sets the value if previously vacant. The provided function is only executed if the entry is vacant.

pub fn or_insert(self, values: impl Into<HeaderValues>) -> &'a mut HeaderValues

Sets the value if previously vacant. See also Entry::or_insert_with if constructing the default value is expensive.

pub fn and_modify(self, f: impl FnOnce(&mut HeaderValues)) -> Self

Provides in-place mutable access to an occupied entry before any potential inserts with Entry::or_insert or Entry::or_insert_with.

pub fn is_vacant(&self) -> bool

Predicate to determine if this is a VacantEntry

pub fn is_occupied(&self) -> bool

Predicate to determine if this is an OccupiedEntry

pub fn occupied(self) -> Option<OccupiedEntry<'a>>

Return the OccupiedEntry, if this entry is occupied

pub fn vacant(self) -> Option<VacantEntry<'a>>

Return the VacantEntry, if this entry is vacant