pub struct HeaderValue(/* private fields */);Expand description
A HeaderValue represents the right hand side of a single name: value pair.
Implementations
Sourceimpl HeaderValue
impl HeaderValue
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
determine if this header contains no unsafe characters (\r, \n, \0)
since 0.3.12
Sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Returns this header value as a &str if it is utf8, None
otherwise. If you need to convert non-utf8 bytes to a string
somehow, match directly on the HeaderValue as an enum and
handle that case. If you need a byte slice regardless of
whether it’s utf8, use the AsRef<[u8]> impl