OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a>(/* private fields */);
A view into an occupied entry in particular Headers for a given HeaderName.

It is part of the Entry enum.

Implementations

Source

impl<'a> OccupiedEntry<'a>

pub fn name(&self) -> HeaderName<'_>

Retrieves the HeaderName for this Entry

pub fn values(&self) -> &HeaderValues

Borrows the HeaderValues for this Entry

pub fn values_mut(&mut self) -> &mut HeaderValues

Mutate the HeaderValues for this Entry

pub fn remove_entry(self) -> (HeaderName<'static>, HeaderValues)

Take ownership of the HeaderName and HeaderValues represented by this entry, removing it from the Headers

pub fn remove(self) -> HeaderValues

Take ownership of the HeaderValues contained in this entry, removing it from the Headers

pub fn into_mut(self) -> &'a mut HeaderValues

Converts this OccupiedEntry into a mutable reference to the value in the entry with a lifetime bound to the Headers itself.

If you need multiple references to the OccupiedEntry, see OccupiedEntry::values_mut

pub fn insert(&mut self, values: impl Into<HeaderValues>) -> HeaderValues

Sets the value of the entry, and returns the entry’s old value.

pub fn append(&mut self, values: impl Into<HeaderValues>)

Adds additional HeaderValues to the existing HeaderValues in this entry.