pub struct VacantEntry<'a>(/* private fields */);Expand description
A view into a vacant entry in particular Headers for a given HeaderName.
It is part of the Entry enum.
Implementations
Sourceimpl<'a> VacantEntry<'a>
impl<'a> VacantEntry<'a>
Sourcepub fn name(&self) -> HeaderName<'_>
pub fn name(&self) -> HeaderName<'_>
Retrieves the HeaderName for this Entry.
Sourcepub fn insert(self, values: impl Into<HeaderValues>) -> &'a mut HeaderValues
pub fn insert(self, values: impl Into<HeaderValues>) -> &'a mut HeaderValues
Replace this VacantEntry with a value, returning a mutable reference to that value.